function Earthquakes_incidence

% Calculates incidence of (local) earthquakes

%  Hans Koster, December 17, 2013

% Read in data; I=number of observations of source data; J=number of 
% earthquakes;

close all hidden
tic

YEAR = '2011';

[Datai]=xlsread('nvm.xlsx',YEAR);
[Dataj]=xlsread('earthquakes_gt1.xlsx',YEAR);

I=length(Datai(:,1));
J=length(Dataj(:,1));

IDi = Datai((1:I),1);
xcoordi = Datai((1:I),2)./1000;
ycoordi = Datai((1:I),3)./1000;

IDj = Dataj((1:J),1);
xcoordj = Dataj((1:J),2)./1000;
ycoordj = Dataj((1:J),3)./1000;
R = Dataj((1:J),5); % Richter scale magnitude

E_mean = zeros(I,3);
E_max = zeros(I,3);

waitbar(0,'Please wait...'); 

for i=1:I

    waitbar(i/I)
    
    dij=(sqrt(abs(xcoordj-xcoordi(i)).^2+abs(ycoordj-ycoordi(i)).^2));
    hdij = sqrt(dij.^2+3.^2);   % Calculate hypocentral distance
    
    k = 1;
    for j = 15:-2.5:0
        KNMI = 1.*((10.*10.^(-1.53+0.74*R-0.00139.*(hdij)-1.33*log10(hdij)))>j);  % PGV in mm/s (instead of cm)
        E(i,k)=sum(KNMI);
        k = k+1;
    end
    
    k = 1;
    for j = [5 2.5 1.5 1 0.5]
        NQuakes = 1.*(dij<j).*(R<1.5);
        F(i,k)=sum(NQuakes);
        k = k+1;
    end  
   
end

table = [IDi E F];

xlswrite('nvm_PGV_gt1.xlsx',table,YEAR)

close all hidden
toc
end
    
