********************************************************************************
*                                                                              *
*                         PREPARE PRICE DATA                                   *
*                                                                              *
********************************************************************************

global cd U:

use "$cd\Completed projects\Earthquakes\Data\NVM_19852014.dta", clear

global eqi_step = 25
global eqi_max = 50

* Transform variables / generate relevant dependent variables
g logpricesqm = ln(pricesqm)
order logpricesqm, after(pricesqm)
g rtrask =  price/priceask
replace rtrask = . if rtrask < 0.5
replace rtrask = . if rtrask > 1.5
order rtrask, after(priceaskadj)
g logsize = ln(size)
order logsize, after(size)
replace daysonmarket = . if daysonmarket < 1
replace daysonmarket = . if daysonmarket > 1461
g logdaysonmarket = ln(daysonmarket)
order logdaysonmarket, after(daysonmarket)

label variable logpricesqm "log of transaction price in  per m2"
label variable rtrask "ratio of asking/transaction price"
label variable logdaysonmarket "log of days on the market"
label variable logsize "log of size of property in m2"

* Merge to location data
merge 1:1 obsid using "$cd\Completed projects\Earthquakes\Data\earthquakes_pgv_DELFT.dta", nogenerate

forvalues i = 150(-$eqi_step)0 {

	if `i' > $eqi_max {
	drop eqpgv_`i' //eq95i_`i' eqavi_`i' eq13i_`i'
	*rop eq13pgv_`i'
	}
	
	if `i'< $eqi_max {
	local j = `i'+$eqi_step
	replace eqpgv_`i' = eqpgv_`i'-eqpgv_`j'
	*replace eq13pgv_`i' = eq13pgv_`i'-eq13pgv_`j'
	
	}
}

if $eqi_step == 50 {
	drop eqpgv_125 eqpgv_75 eqpgv_25
	*drop eq13pgv_125 eq13pgv_75 eq13pgv_25
}



order eq*, after(logdaysonmarket)


merge m:1 xcoord ycoord using "$cd\Completed projects\Earthquakes\Data\sharedamage.dta", nogenerate keep(1 3)
replace shdamage = 0 if shdamage == .
replace soilsubs = 0 if soilsubs == .
merge m:1 xcoord ycoord year using "$cd\Data\Residential property data (NVM)\1985-2014\NVM_GIS_xy.dta", nogenerate keep(1 3) keepusing(popdens logpopdens shyoung shelderly shforeign hhsize lu_res lu_ind lu_infr lu_opensp lu_water distramp diststat)
drop if lu_res ==. & year > 1995

g distrid = substr(nid,1,8)
replace popdens = 0 if popdens < 0 | popdens == .
replace logpopdens = 0 if logpopdens == .
replace hhsize = 0 if hhsize < 0 | hhsize > 10
summ shyoung 
replace shyoung = shyoung/100
replace shelderly = shelderly/100
replace shforeign = shforeign/100
replace shyoung = . if shyoung < 0 | shyoung > 1
replace shelderly = . if shelderly < 0 | shelderly > 1
replace shforeign = . if shforeign < 0 | shforeign > 1

bysort distrid: egen shyoung_distr = mean(shyoung)
bysort mun: egen shyoung_mun = mean(shyoung)
replace shyoung = shyoung_distr if shyoung ==.
replace shyoung = shyoung_mun if shyoung ==.
drop shyoung_*

bysort distrid: egen shelderly_distr = mean(shelderly)
bysort mun: egen shelderly_mun = mean(shelderly)
replace shelderly = shelderly_distr if shelderly ==.
replace shelderly = shelderly_mun if shelderly ==.
drop shelderly_*

bysort distrid: egen shforeign_distr = mean(shforeign)
bysort mun: egen shforeign_mun = mean(shforeign)
replace shforeign = shforeign_distr if shforeign ==.
replace shforeign = shforeign_mun if shforeign ==.
drop shforeign_*

g station250 = 0
replace station250 = 1 if diststat < 0.25
g station500 = 0
replace station500 = 1 if diststat < 0.5 & station250==0
g hwramp250 = 0
replace hwramp250 = 1 if distramp < 0.25
g hwramp500 = 0
replace hwramp500 = 1 if distramp < 0.5 & hwramp250==0
drop distramp diststat

save "$cd\Completed projects\Earthquakes\Data\NVM_19852014_cs.dta", replace
