********************************************************************************
*                                                                              *
*                        REGRESSIONS - FIXED EFFECTS                           *
*                                                                              *
********************************************************************************

global cd U:\Completed projects\Earthquakes
quietly set matsize 2500

/// Set parameters \\\
global yearmin 1996
global yearmax 2014
local eqndist 1000

/// Define variables \\\
global dependent logpricesqm
*global dependent rtrask
*global dependent daysonmarket
global eqvar eqpgv_50
global housing logsize rooms terraced semidetached detached garage garden centralheating listed constr19451959 constr19601970 constr19711980 constr19811990 constr19912000 constrgt2000 
global neighbourhood logpopdens shyoung shelderly shforeign hhsize lu_ind lu_infr lu_opensp lu_water
global eqn eqn_`eqndist'
global trend eqn_`eqndist'_*
global muntrend mun_*
global year i.year 
global instruments ngfproduction
global cluster nid
global fe pc6

quietly use "$cd\Data\NVM_19852014_cs.dta", clear 

*g loglotsize = ln(lotsize)


quietly forvalues i = 1(1)5 {
	g eqn_5000_`i' = eqn_5000^`i'
	g eqn_2500_`i' = eqn_2500^`i'
	g eqn_1500_`i' = eqn_1500^`i'
	g eqn_1000_`i' = eqn_1000^`i'
	g eqn_500_`i' = eqn_500^`i'
}

/*
g eqpgv_50g = eqpgv_50*(mun==14)
g eqpgv_50ng = eqpgv_50*(mun!=14)
*/
g groningenXyear = (mun==14)*year
g groningenXyear2 = (mun==14)*year^2 




********************************************************************************
*                                 SECTION III.A                                *
********************************************************************************

/*
/// Estimate regressions with 2013-2014 data\\\
quietly regress $dependent $eqvar $year, cluster($cluster), if year >= $yearmin & year <= $yearmax
quietly estimates store reg1_1
quietly areg $dependent $eqvar $year, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg1_2
quietly areg $dependent $eqvar $housing $year, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg1_3
quietly areg $dependent $eqvar $housing $year $eqn, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg1_4
quietly areg $dependent $eqvar $housing $neighbourhood $year $eqn, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg1_5
quietly areg $dependent $eqvar $housing $neighbourhood $year $trend, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg1_6
estimates table reg1_1 reg1_2 reg1_3 reg1_4 reg1_5 reg1_6, b(%8.5f) se(%8.5f) p(%8.5f) stats(N r2 widstat) keep($eqvar $eqn $housing $neighbourhood) title(table X - results)

/// Estimate regressions with 2013-2014 data\\\
quietly regress $dependent $eqvar loglotsize $year, cluster($cluster), if year >= $yearmin & year <= $yearmax
quietly estimates store reg2_1
quietly areg $dependent $eqvar loglotsize $year, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg2_2
quietly areg $dependent $eqvar loglotsize $housing $year, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg2_3
quietly areg $dependent $eqvar loglotsize $housing $year $eqn, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg2_4
quietly areg $dependent $eqvar loglotsize $housing $neighbourhood $year $eqn, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg2_5
quietly areg $dependent $eqvar loglotsize $housing $neighbourhood $year $trend, cluster($cluster) absorb($fe), if year >= $yearmin & year <= $yearmax
quietly estimates store reg2_6
estimates table reg2_1 reg2_2 reg2_3 reg2_4 reg2_5 reg2_6, b(%8.5f) se(%8.5f) p(%8.5f) stats(N r2 widstat) keep($eqvar $eqn $housing $neighbourhood) title(table X - results)


********************************************************************************
*                                 SECTION III.B                                *
********************************************************************************
*/
drop if provid != 1
g longdiffinclude = (year <= 1991)
replace longdiffinclude = 0 if (year == 1991 & month == 12)
replace longdiffinclude = 1 if year == 2014
replace longdiffinclude = 1 if year == 2013
replace longdiffinclude = 1 if year == 2012 & month > 8

/*
quietly regress $dependent shdamage $housing $neighbourhood $year $trend, cluster($cluster), if (year == 2012 & month > 8) | year > 2012
quietly estimates store reg3_1
quietly regress $dependent $eqvar soilsubs $housing $neighbourhood $year $trend, cluster($cluster), if (year == 2012 & month > 8) | year > 2012
quietly estimates store reg3_2
quietly regress $dependent shdamage $eqvar soilsubs $housing $neighbourhood $year $trend, cluster($cluster), if (year == 2012 & month > 8) | year > 2012
quietly estimates store reg3_3
quietly areg $dependent shdamage $housing $neighbourhood $year $trend, cluster($cluster) absorb(mun), if (year == 2012 & month > 8) | year > 2012
quietly estimates store reg3_4
quietly areg $dependent $eqvar soilsubs $housing $neighbourhood $year $trend, cluster($cluster) absorb(mun), if (year == 2012 & month > 8) | year > 2012
quietly estimates store reg3_5
quietly areg $dependent shdamage $eqvar soilsubs $housing $neighbourhood $year $trend, cluster($cluster) absorb(mun), if (year == 2012 & month > 8) | year > 2012
quietly estimates store reg3_6
*/

quietly replace shdamage = 0 if year <= 1991
g shdamage_0025 = shdamage*(shdamage<=0.25 & year > 1991)
g shdamage_2550 = shdamage*(shdamage>0.25 & shdamage <= 0.5 & year > 1991)
g shdamage_50100 = shdamage*(shdamage>0.5 & year > 1991)

g shdamagegr = shdamage*(mun==14)
g shdamagengr = shdamage*(mun!=14)
g groningen = (mun==14 & year > 2011)

quietly areg $dependent shdamage $housing $year $trend, cluster($cluster) absorb($fe), if longdiffinclude == 1
quietly estimates store reg4_1
quietly areg $dependent $eqvar $housing $year $trend, cluster($cluster) absorb($fe), if longdiffinclude == 1
quietly estimates store reg4_2
quietly areg $dependent shdamage $eqvar $housing $year $trend, cluster($cluster) absorb($fe), if longdiffinclude == 1
quietly estimates store reg4_3


areg $dependent shdamage $housing $year $trend, cluster($cluster) absorb($fe), if longdiffinclude == 1

********************************************************************************
*                                 EXPORT RESULTS                               *
********************************************************************************

keep if year >= $yearmin & year <= $yearmax
outreg2 using "$cd\Results\Table 1, Delft", replace sum(log) label word keep(pricesqm $eqvar $eqn shdamage soilsubs lotsize size rooms apartment terraced semidetached detached garage garden centralheating listed constrlt1945 constr19451959 constr19601970 constr19711980 constr19811990 constr19912000 constrgt2000 popdens shyoung shelderly shforeign hhsize lu_res lu_ind lu_infr lu_opensp lu_water station250 station500 hwramp250 hwramp500)

estimates restore reg1_1
outreg2 $eqvar $housing using "$cd\Results\Table 2, Delft", label aster replace word title(Results) ctitle(OLS) nocon 
estimates restore reg1_2
outreg2 $eqvar $housing using "$cd\Results\Table 2, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg1_3
outreg2 $eqvar $housing using "$cd\Results\Table 2, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg1_4
outreg2 $eqvar $housing using "$cd\Results\Table 2, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg1_5
outreg2 $eqvar $housing using "$cd\Results\Table 2, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg1_6
outreg2 $eqvar $housing using "$cd\Results\Table 2, Delft", append label aster word ctitle(OLS) nocon 

estimates restore reg2_1
outreg2 $eqvar $housing using "$cd\Results\Table 3, Delft", label aster replace word title(Results) ctitle(OLS) nocon 
estimates restore reg2_2
outreg2 $eqvar $housing using "$cd\Results\Table 3, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg2_3
outreg2 $eqvar $housing using "$cd\Results\Table 3, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg2_4
outreg2 $eqvar $housing using "$cd\Results\Table 3, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg2_5
outreg2 $eqvar $housing using "$cd\Results\Table 3, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg2_6
outreg2 $eqvar $housing using "$cd\Results\Table 3, Delft", append label aster word ctitle(OLS) nocon 

estimates restore reg3_1
outreg2 $eqvar $housing using "$cd\Results\Table 4, Delft", label aster replace word title(Results) ctitle(OLS) nocon 
estimates restore reg3_2
outreg2 $eqvar $housing using "$cd\Results\Table 4, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg3_3
outreg2 $eqvar $housing using "$cd\Results\Table 4, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg3_4
outreg2 $eqvar $housing using "$cd\Results\Table 4, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg3_5
outreg2 $eqvar $housing using "$cd\Results\Table 4, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg3_6
outreg2 $eqvar $housing using "$cd\Results\Table 4, Delft", append label aster word ctitle(OLS) nocon 

estimates restore reg4_1
outreg2 $eqvar $housing using "$cd\Results\Table 5, Delft", label aster replace word title(Results) ctitle(OLS) nocon 
estimates restore reg4_2
outreg2 $eqvar $housing using "$cd\Results\Table 5, Delft", append label aster word ctitle(OLS) nocon 
estimates restore reg4_3
outreg2 $eqvar $housing using "$cd\Results\Table 5, Delft", append label aster word ctitle(OLS) nocon 
