********************************************************************************
*                                                                              *
*                         PREPARE PRICE DATA                                   *
*                                                                              *
********************************************************************************

global cd U:

use "$cd\Completed projects\Earthquakes\Data\NVM_19852013.dta", clear

global eqi_step = 25
global eqi_max = 50

* Transform variables / generate relevant dependent variables
g logpricesqm = ln(pricesqm)
order logpricesqm, after(pricesqm)
g rtrask =  price/priceask
replace rtrask = . if rtrask < 0.5
replace rtrask = . if rtrask > 1.5
order rtrask, after(priceaskadj)
g logsize = ln(size)
order logsize, after(size)
replace daysonmarket = . if daysonmarket < 1
replace daysonmarket = . if daysonmarket > 1461
g logdaysonmarket = ln(daysonmarket)
order logdaysonmarket, after(daysonmarket)

label variable logpricesqm "log of transaction price in  per m2"
label variable rtrask "ratio of asking/transaction price"
label variable logdaysonmarket "log of days on the market"
label variable logsize "log of size of property in m2"

drop date date2

* Merge to location data
merge 1:1 obsid using "$cd\Completed projects\Earthquakes\Data\earthquakes_pgv_new.dta", nogenerate
merge 1:1 obsid using "$cd\Completed projects\Earthquakes\Data\earthquakes_tiv_new.dta", nogenerate 

forvalues i = 150(-$eqi_step)0 {

	if `i' > $eqi_max {
	drop eqpgv_`i'
	drop eq13pgv_`i'
	}
	
	if `i'< $eqi_max {
	local j = `i'+$eqi_step
	replace eqpgv_`i' = eqpgv_`i'-eqpgv_`j'
	replace eq13pgv_`i' = eq13pgv_`i'-eq13pgv_`j'
	
	}
}

if $eqi_step == 50 {
	drop eqpgv_125 eqpgv_75 eqpgv_25
	drop eq13pgv_125 eq13pgv_75 eq13pgv_25
}



order eq*, after(logdaysonmarket)

merge 1:1 obsid using "$cd\Completed projects\Earthquakes\Data\naturalgasfields.dta", nogenerate
merge 1:1 obsid using "$cd\Completed projects\Earthquakes\Data\NVM_areacodes.dta", nogenerate keep(1 3) 
merge 1:1 obsid using "$cd\Data\Residential property data (NVM)\1985-2013\nvm_location.dta", nogenerate keep(1 3) keepusing(popdens logpopdens shyoung shelderly shforeign shwforeign shnwforeign hhsize lu_res lu_ind lu_infr lu_opensp lu_water distramp logdistramp diststat logdiststat hdid hddist hdinproc hdcompl)
g station250 = 0
replace station250 = 1 if diststat < 0.25
g station500 = 0
replace station500 = 1 if diststat < 0.5 & station250==0
g hwramp250 = 0
replace hwramp250 = 1 if distramp < 0.25
g hwramp500 = 0
replace hwramp500 = 1 if distramp < 0.5 & hwramp250==0
drop distramp logdistramp diststat logdiststat hdid hddist shwforeign shnwforeign

save "$cd\Completed projects\Earthquakes\Data\NVM_19852013_cs.dta", replace
