********************************************************************************
*                                                                              *
*                        REGRESSIONS - FIXED EFFECTS                           *
*                                                                              *
********************************************************************************

global cd U:\Current projects\Earthquakes
quietly set matsize 2500

quietly net set ado "$cd\Results\Stata"
quietly adopath + "$cd\Results\Stata"

/// Set parameters \\\
global yearmin 1996
global yearmax 2013
local eqndist 1000

/// Define variables \\\
global dependent logpricesqm
*global dependent rtrask
*global dependent daysonmarket
global eqvar eqpgv_50
global housing logsize rooms terraced semidetached detached garage garden centralheating listed constr19451959 constr19601970 constr19711980 constr19811990 constr19912000 constrgt2000 
global neighbourhood logpopdens shyoung shelderly shforeign hhsize lu_ind lu_infr lu_opensp lu_water
global eqn eqn_`eqndist'
global trend eqn_`eqndist'_*
global muntrend mun_*
global year i.year
global instruments ngfproduction
global cluster nid
global fe pc6

quietly use "$cd\Data\NVM_19852013_cs.dta", clear 
quietly keep if provid==3
quietly drop if year < $yearmin
quietly drop if year > $yearmax

quietly forvalues i = 1(1)5 {
	g eqn_5000_`i' = eqn_5000^`i'
	g eqn_2500_`i' = eqn_2500^`i'
	g eqn_1500_`i' = eqn_1500^`i'
	g eqn_1000_`i' = eqn_1000^`i'
	g eqn_500_`i' = eqn_500^`i'
}


/// Estimate regressions \\\
 
quietly regress $dependent $eqvar $year, cluster($cluster)
quietly estimates store reg1
quietly areg $dependent $eqvar $year, cluster($cluster) absorb($fe)
quietly estimates store reg2
quietly areg $dependent $eqvar $housing $year, cluster($cluster) absorb($fe)
quietly estimates store reg3
quietly areg $dependent $eqvar $housing $year $eqn, cluster($cluster) absorb($fe)
quietly estimates store reg4
quietly areg $dependent $eqvar $housing $neighbourhood $year $eqn, cluster($cluster) absorb($fe)
quietly estimates store reg5
quietly areg $dependent $eqvar $housing $neighbourhood $year $trend, cluster($cluster) absorb($fe)
quietly estimates store reg6

estimates table reg1 reg2 reg3 reg4 reg5 reg6, b(%8.5f) se(%8.5f) p(%8.5f) stats(N r2 widstat) keep($eqvar $eqn $housing $neighbourhood) title(table X - results)


/// Export results \\\

replace distngf = 0 if distngf > 0
replace distngf = abs(distngf)

outreg2 using "$cd\Results\Table 1", replace sum(log) label word keep(pricesqm $eqvar $eqn soilsubs distngf size rooms apartment terraced semidetached detached garage garden centralheating listed constrlt1945 constr19451959 constr19601970 constr19711980 constr19811990 constr19912000 constrgt2000 popdens shyoung shelderly shforeign hhsize lu_res lu_ind lu_infr lu_opensp lu_water hdinproc hdcompl station250 station500 hwramp250 hwramp500)

estimates restore reg1
outreg2 $eqvar $housing using "$cd\Results\Table 2", label aster replace word title(Results) ctitle(OLS) nocon 
estimates restore reg2
outreg2 $eqvar $housing using "$cd\Results\Table 2", append label aster word ctitle(OLS) nocon 
estimates restore reg3
outreg2 $eqvar $housing using "$cd\Results\Table 2", append label aster word ctitle(OLS) nocon 
estimates restore reg4
outreg2 $eqvar $housing using "$cd\Results\Table 2", append label aster word ctitle(OLS) nocon 
estimates restore reg5
outreg2 $eqvar $housing using "$cd\Results\Table 2", append label aster word ctitle(OLS) nocon 
estimates restore reg6
outreg2 $eqvar $housing using "$cd\Results\Table 2", append label aster word ctitle(OLS) nocon 
